--#SET TERMINATOR ;

-- =============================================
-- Application: Sample 13 - Tests
-- Version 10.8, January 9, 2023
--
-- Copyright 2021-2023 Gartle LLC
--
-- License: MIT
-- =============================================

CREATE SCHEMA S13;

CREATE TABLE S13.QUOTES (
      "'" VARCHAR(50) NOT NULL
    , "''" VARCHAR(50) NOT NULL
    , "," VARCHAR(50) NOT NULL
    , "-" VARCHAR(50) NOT NULL
    , "@" VARCHAR(50) NOT NULL
    , "@@" VARCHAR(50) NOT NULL
    , "`" VARCHAR(50) NULL
    , "``" VARCHAR(50) NULL
    , """" VARCHAR(50) NULL
    , """""" VARCHAR(50) NULL
    , "]" VARCHAR(50) NULL
    , "[" VARCHAR(50) NULL
    , "[]" VARCHAR(50) NULL
    , "+" VARCHAR(50) NULL
    , "*" VARCHAR(50) NULL
    , "%" VARCHAR(50) NULL
    , "%%" VARCHAR(50) NULL
    , "=" VARCHAR(50) NULL
    , ";" VARCHAR(50) NULL
    , ":" VARCHAR(50) NULL
    , "<>" VARCHAR(50) NULL
    , "&" VARCHAR(50) NULL
    , "." VARCHAR(50) NULL
    , ".." VARCHAR(50) NULL
    , CONSTRAINT PK_QUOTES PRIMARY KEY ("'", "''", ",", "-", "@", "@@")
);

CREATE TABLE S13.DATATYPES (
    ID INTEGER NOT NULL GENERATED BY DEFAULT AS IDENTITY
    , "BIGINT" BIGINT NULL
    , "BINARY" BINARY(8) NULL
    , "BINARY16" BINARY(16) NULL
    , "BLOB" BLOB NULL
    , "CHAR" CHARACTER(10) NULL
    , "CHAR36" CHARACTER(36) NULL
    , "CLOB" CLOB NULL
    , "DATE" DATE NULL
    , "DBCLOB" DBCLOB NULL
    , "DECFLOAT" DECFLOAT NULL
    , "DECIMAL152" DECIMAL(15,2) NULL
    , "DECIMAL154" DECIMAL(15,4) NULL
    , "DECIMAL310" DECIMAL(31,0) NULL
    , "DECIMAL314" DECIMAL(31,4) NULL
    , "DOUBLE" DOUBLE NULL
    , "GRAPHIC" GRAPHIC(10) NULL
    , "INTEGER" INTEGER NULL
    , "REAL" REAL NULL
    , "SMALLINT" SMALLINT NULL
    , "TIME" TIME NULL
    , "TIMESTAMP" TIMESTAMP NULL
    , "TIMESTAMP0" TIMESTAMP(0) NULL
    , "TIMESTAMP3" TIMESTAMP(3) NULL
    , "VARBINARY" VARBINARY(1024) NULL
    , "VARCHAR" VARCHAR(255) NULL
    , "VARGRAPHIC" VARGRAPHIC(1024) NULL
    , "XML" XML NULL
    , CONSTRAINT PK_DATATYPES PRIMARY KEY (ID)
);

CREATE OR REPLACE VIEW S13.VIEW_DATATYPE_COLUMNS
AS
SELECT
    c.TABSCHEMA AS TABLE_SCHEMA
    , c.TABNAME AS TABLE_NAME
    , c.COLNAME AS COLUMN_NAME
    , c.COLNO AS ORDINAL_POSITION
    , CASE WHEN i.INDNAME IS NULL THEN 'NO' ELSE 'YES' END AS IS_PRIMARY_KEY
    , c.NULLS AS IS_NULLABLE
    , c.IDENTITY AS IS_IDENTITY
    , CASE WHEN c.IDENTITY = 'Y' THEN NULL WHEN c.GENERATED = 'A' THEN 1 ELSE NULL END AS IS_COMPUTED
    , CAST(c.DEFAULT AS LONG VARCHAR) AS COLUMN_DEFAULT
    , c.TYPENAME AS DATA_TYPE
    , c.LENGTH AS MAX_LENGTH
    , c.LENGTH AS PRECISION
    , c.SCALE AS SCALE
FROM
    SYSCAT.COLUMNS c
    LEFT OUTER JOIN SYSCAT.KEYCOLUSE s ON s.TABSCHEMA = c.TABSCHEMA AND s.TABNAME = c.TABNAME AND s.COLNAME = c.COLNAME
    LEFT OUTER JOIN SYSCAT.INDEXES i   ON i.TABSCHEMA = s.TABSCHEMA AND s.CONSTNAME = i.INDNAME AND i.UNIQUERULE = 'P'
WHERE
    c.TABSCHEMA NOT IN ('SYSCAT', 'SYSIBM', 'SYSIBMADM', 'SYSTOOLS', 'SYSSTAT')
    AND c.TABNAME = 'DATATYPES';

CREATE OR REPLACE VIEW S13.VIEW_DATATYPE_PARAMETERS
AS
SELECT
    p.ROUTINESCHEMA AS SPECIFIC_SCHEMA
    , p.ROUTINENAME AS SPECIFIC_NAME
    , p.ORDINAL AS ORDINAL_POSITION
    , CASE p.ROWTYPE
        WHEN 'P' THEN 'IN'
        WHEN 'B' THEN 'INOUT'
        ELSE p.ROWTYPE
        END AS PARAMETER_MODE
    , p.PARMNAME AS PARAMETER_NAME
    , p.TYPENAME AS DATA_TYPE
    , p.LENGTH AS MAX_LENGTH
    , p.LENGTH AS PRECISION
    , p.SCALE AS SCALE
FROM
    SYSCAT.ROUTINEPARMS p
WHERE
    p.ROUTINENAME IN ('USP_DATATYPES', 'USP_DATATYPES_INSERT', 'USP_DATATYPES_UPDATE', 'USP_DATATYPES_DELETE');

--#SET TERMINATOR %%

CREATE OR REPLACE PROCEDURE S13.USP_QUOTES (
    )
    READS SQL DATA
    DETERMINISTIC
    CALLED ON NULL INPUT
    LANGUAGE SQL
P1: BEGIN

DECLARE Cursor1 CURSOR WITH RETURN FOR
SELECT
      t."'"
    , t."''"
    , t.","
    , t."-"
    , t."@"
    , t."@@"
    , t."`"
    , t."``"
    , t.""""
    , t.""""""
    , t."]"
    , t."["
    , t."[]"
    , t."+"
    , t."*"
    , t."%"
    , t."%%"
    , t."="
    , t.";"
    , t.":"
    , t."<>"
    , t."&"
    , t."."
    , t.".."
FROM
    S13.QUOTES t;

OPEN Cursor1;

END P1
%%

CREATE OR REPLACE PROCEDURE S13.USP_QUOTES_DELETE (
    "_x0027_" VARCHAR(50)
    , "_x0027__x0027_" VARCHAR(50)
    , "_x002C_" VARCHAR(50)
    , "_x002D_" VARCHAR(50)
    , "_x0040_" VARCHAR(50)
    , "_x0040__x0040_" VARCHAR(50)
    )
    MODIFIES SQL DATA
    NOT DETERMINISTIC
    CALLED ON NULL INPUT
    COMMIT ON RETURN YES
    LANGUAGE SQL
P1: BEGIN

DELETE FROM S13.QUOTES
WHERE
    "'" = "_x0027_"
    AND "''" = "_x0027__x0027_"
    AND "," = "_x002C_"
    AND "-" = "_x002D_"
    AND "@" = "_x0040_"
    AND "@@" = "_x0040__x0040_";

END P1
%%

CREATE OR REPLACE PROCEDURE S13.USP_QUOTES_INSERT (
    "_x0027_" VARCHAR(50)
    , "_x0027__x0027_" VARCHAR(50)
    , "_x002C_" VARCHAR(50)
    , "_x002D_" VARCHAR(50)
    , "_x0040_" VARCHAR(50)
    , "_x0040__x0040_" VARCHAR(50)
    , "_x0060_" VARCHAR(50)
    , "_x0060__x0060_" VARCHAR(50)
    , "_x0022_" VARCHAR(50)
    , "_x0022__x0022_" VARCHAR(50)
    , "_x005D_" VARCHAR(50)
    , "_x005B_" VARCHAR(50)
    , "_x005B__x005D_" VARCHAR(50)
    , "_x002B_" VARCHAR(50)
    , "_x002A_" VARCHAR(50)
    , "_x0025_" VARCHAR(50)
    , "_x0025__x0025_" VARCHAR(50)
    , "_x003D_" VARCHAR(50)
    , "_x003B_" VARCHAR(50)
    , "_x003A_" VARCHAR(50)
    , "_x003C__x003E_" VARCHAR(50)
    , "_x0026_" VARCHAR(50)
    , "_x002E_" VARCHAR(50)
    , "_x002E__x002E_" VARCHAR(50)
    )
    MODIFIES SQL DATA
    NOT DETERMINISTIC
    CALLED ON NULL INPUT
    COMMIT ON RETURN YES
    LANGUAGE SQL
P1: BEGIN

INSERT INTO S13.QUOTES
    ( "'"
    , "''"
    , ","
    , "-"
    , "@"
    , "@@"
    , "`"
    , "``"
    , """"
    , """"""
    , "]"
    , "["
    , "[]"
    , "+"
    , "*"
    , "%"
    , "%%"
    , "="
    , ";"
    , ":"
    , "<>"
    , "&"
    , "."
    , ".."
    )
VALUES
    ( "_x0027_"
    , "_x0027__x0027_"
    , "_x002C_"
    , "_x002D_"
    , "_x0040_"
    , "_x0040__x0040_"
    , "_x0060_"
    , "_x0060__x0060_"
    , "_x0022_"
    , "_x0022__x0022_"
    , "_x005D_"
    , "_x005B_"
    , "_x005B__x005D_"
    , "_x002B_"
    , "_x002A_"
    , "_x0025_"
    , "_x0025__x0025_"
    , "_x003D_"
    , "_x003B_"
    , "_x003A_"
    , "_x003C__x003E_"
    , "_x0026_"
    , "_x002E_"
    , "_x002E__x002E_"
    );

END P1
%%

CREATE OR REPLACE PROCEDURE S13.USP_QUOTES_UPDATE (
    "_x0027_" VARCHAR(50)
    , "_x0027__x0027_" VARCHAR(50)
    , "_x002C_" VARCHAR(50)
    , "_x002D_" VARCHAR(50)
    , "_x0040_" VARCHAR(50)
    , "_x0040__x0040_" VARCHAR(50)
    , "_x0060_" VARCHAR(50)
    , "_x0060__x0060_" VARCHAR(50)
    , "_x0022_" VARCHAR(50)
    , "_x0022__x0022_" VARCHAR(50)
    , "_x005D_" VARCHAR(50)
    , "_x005B_" VARCHAR(50)
    , "_x005B__x005D_" VARCHAR(50)
    , "_x002B_" VARCHAR(50)
    , "_x002A_" VARCHAR(50)
    , "_x0025_" VARCHAR(50)
    , "_x0025__x0025_" VARCHAR(50)
    , "_x003D_" VARCHAR(50)
    , "_x003B_" VARCHAR(50)
    , "_x003A_" VARCHAR(50)
    , "_x003C__x003E_" VARCHAR(50)
    , "_x0026_" VARCHAR(50)
    , "_x002E_" VARCHAR(50)
    , "_x002E__x002E_" VARCHAR(50)
    )
    MODIFIES SQL DATA
    NOT DETERMINISTIC
    CALLED ON NULL INPUT
    COMMIT ON RETURN YES
    LANGUAGE SQL
P1: BEGIN

UPDATE S13.QUOTES
SET
    "`" = "_x0060_"
    , "``" = "_x0060__x0060_"
    , """" = "_x0022_"
    , """""" = "_x0022__x0022_"
    , "]" = "_x005D_"
    , "[" = "_x005B_"
    , "[]" = "_x005B__x005D_"
    , "+" = "_x002B_"
    , "*" = "_x002A_"
    , "%" = "_x0025_"
    , "%%" = "_x0025__x0025_"
    , "=" = "_x003D_"
    , ";" = "_x003B_"
    , ":" = "_x003A_"
    , "<>" = "_x003C__x003E_"
    , "&" = "_x0026_"
    , "." = "_x002E_"
    , ".." = "_x002E__x002E_"
WHERE
    "'" = "_x0027_"
    AND "''" = "_x0027__x0027_"
    AND "," = "_x002C_"
    AND "-" = "_x002D_"
    AND "@" = "_x0040_"
    AND "@@" = "_x0040__x0040_";

END P1
%%

CREATE OR REPLACE PROCEDURE S13.USP_DATATYPES (
    )
    READS SQL DATA
    DETERMINISTIC
    CALLED ON NULL INPUT
    LANGUAGE SQL
P1: BEGIN

DECLARE Cursor1 CURSOR WITH RETURN FOR
SELECT
    t."ID"
    , t."BIGINT"
    , t."BINARY"
    , VARCHAR_FORMAT_BIT(CAST("BINARY16" AS CHAR(16) FOR BIT DATA), 'xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx') AS "BINARY16"
    , t."BLOB"
    , t."CHAR"
    , t."CHAR36"
    , t."CLOB"
    , t."DATE"
    , t."DBCLOB"
    , t."DECFLOAT"
    , t."DECIMAL152"
    , t."DECIMAL154"
    , t."DECIMAL310"
    , t."DECIMAL314"
    , t."DOUBLE"
    , t."GRAPHIC"
    , t."INTEGER"
    , t."REAL"
    , t."SMALLINT"
    , t."TIME"
    , t."TIMESTAMP"
    , t."TIMESTAMP0"
    , t."TIMESTAMP3"
    , t."VARBINARY"
    , t."VARCHAR"
    , t."VARGRAPHIC"
    , t."XML"
FROM
    S13.DATATYPES t;

OPEN Cursor1;

END P1
%%

CREATE OR REPLACE PROCEDURE S13.USP_DATATYPES_DELETE (
    ID INTEGER
    )
    MODIFIES SQL DATA
    NOT DETERMINISTIC
    CALLED ON NULL INPUT
    COMMIT ON RETURN YES
    LANGUAGE SQL
P1: BEGIN

DELETE FROM S13.DATATYPES t
WHERE
    t.ID = USP_DATATYPES_DELETE.ID;

END P1
%%

CREATE OR REPLACE PROCEDURE S13.USP_DATATYPES_INSERT (
    "BIGINT" BIGINT
    , "BINARY" BINARY(8)
    , "BINARY16" CHARACTER(36)
    , "BLOB" BLOB
    , "CHAR" CHARACTER(10)
    , "CHAR36" CHARACTER(36)
    , "CLOB" CLOB
    , "DATE" DATE
    , "DBCLOB" DBCLOB
    , "DECFLOAT" DECFLOAT
    , "DECIMAL152" DECIMAL(15,2)
    , "DECIMAL154" DECIMAL(15,4)
    , "DECIMAL310" DECIMAL(31,0)
    , "DECIMAL314" DECIMAL(31,4)
    , "DOUBLE" DOUBLE
    , "GRAPHIC" GRAPHIC(10)
    , "INTEGER" INTEGER
    , "REAL" REAL
    , "SMALLINT" SMALLINT
    , "TIME" TIME
    , "TIMESTAMP" TIMESTAMP
    , "TIMESTAMP0" TIMESTAMP(0)
    , "TIMESTAMP3" TIMESTAMP(3)
    , "VARBINARY" VARBINARY(1024)
    , "VARCHAR" VARCHAR(255)
    , "VARGRAPHIC" VARGRAPHIC(1024)
    , "XML" XML
    )
    MODIFIES SQL DATA
    NOT DETERMINISTIC
    CALLED ON NULL INPUT
    COMMIT ON RETURN YES
    LANGUAGE SQL
P1: BEGIN

INSERT INTO S13.DATATYPES
    ( "BIGINT"
    , "BINARY"
    , "BINARY16"
    , "BLOB"
    , "CHAR"
    , "CHAR36"
    , "CLOB"
    , "DATE"
    , "DBCLOB"
    , "DECFLOAT"
    , "DECIMAL152"
    , "DECIMAL154"
    , "DECIMAL310"
    , "DECIMAL314"
    , "DOUBLE"
    , "GRAPHIC"
    , "INTEGER"
    , "REAL"
    , "SMALLINT"
    , "TIME"
    , "TIMESTAMP"
    , "TIMESTAMP0"
    , "TIMESTAMP3"
    , "VARBINARY"
    , "VARCHAR"
    , "VARGRAPHIC"
    , "XML"
    )
VALUES
    ( "BIGINT"
    , "BINARY"
    , VARCHAR_BIT_FORMAT(LOWER("BINARY16"),'xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx')
    , "BLOB"
    , "CHAR"
    , "CHAR36"
    , "CLOB"
    , "DATE"
    , "DBCLOB"
    , "DECFLOAT"
    , "DECIMAL152"
    , "DECIMAL154"
    , "DECIMAL310"
    , "DECIMAL314"
    , "DOUBLE"
    , "GRAPHIC"
    , "INTEGER"
    , "REAL"
    , "SMALLINT"
    , "TIME"
    , "TIMESTAMP"
    , "TIMESTAMP0"
    , "TIMESTAMP3"
    , "VARBINARY"
    , "VARCHAR"
    , "VARGRAPHIC"
    , "XML"
    );

END P1
%%

CREATE OR REPLACE PROCEDURE S13.USP_DATATYPES_UPDATE (
    "ID" INTEGER
    , "BIGINT" BIGINT
    , "BINARY" BINARY(8)
    , "BINARY16" CHARACTER(36)
    , "BLOB" BLOB
    , "CHAR" CHARACTER(10)
    , "CHAR36" CHARACTER(36)
    , "CLOB" CLOB
    , "DATE" DATE
    , "DBCLOB" DBCLOB
    , "DECFLOAT" DECFLOAT
    , "DECIMAL152" DECIMAL(15,2)
    , "DECIMAL154" DECIMAL(15,4)
    , "DECIMAL310" DECIMAL(31,0)
    , "DECIMAL314" DECIMAL(31,4)
    , "DOUBLE" DOUBLE
    , "GRAPHIC" GRAPHIC(10)
    , "INTEGER" INTEGER
    , "REAL" REAL
    , "SMALLINT" SMALLINT
    , "TIME" TIME
    , "TIMESTAMP" TIMESTAMP
    , "TIMESTAMP0" TIMESTAMP(0)
    , "TIMESTAMP3" TIMESTAMP(3)
    , "VARBINARY" VARBINARY(1024)
    , "VARCHAR" VARCHAR(255)
    , "VARGRAPHIC" VARGRAPHIC(1024)
    , "XML" XML
    )
    MODIFIES SQL DATA
    NOT DETERMINISTIC
    CALLED ON NULL INPUT
    COMMIT ON RETURN YES
    LANGUAGE SQL
P1: BEGIN

UPDATE S13.DATATYPES
SET
    "BIGINT" = USP_DATATYPES_UPDATE."BIGINT"
    , "BINARY" = USP_DATATYPES_UPDATE."BINARY"
    , "BINARY16" = VARCHAR_BIT_FORMAT(LOWER(USP_DATATYPES_UPDATE."BINARY16"), 'xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx')
    , "BLOB" = USP_DATATYPES_UPDATE."BLOB"
    , "CHAR" = USP_DATATYPES_UPDATE."CHAR"
    , "CHAR36" = USP_DATATYPES_UPDATE."CHAR36"
    , "CLOB" = USP_DATATYPES_UPDATE."CLOB"
    , "DATE" = USP_DATATYPES_UPDATE."DATE"
    , "DBCLOB" = USP_DATATYPES_UPDATE."DBCLOB"
    , "DECFLOAT" = USP_DATATYPES_UPDATE."DECFLOAT"
    , "DECIMAL152" = USP_DATATYPES_UPDATE."DECIMAL152"
    , "DECIMAL154" = USP_DATATYPES_UPDATE."DECIMAL154"
    , "DECIMAL310" = USP_DATATYPES_UPDATE."DECIMAL310"
    , "DECIMAL314" = USP_DATATYPES_UPDATE."DECIMAL314"
    , "DOUBLE" = USP_DATATYPES_UPDATE."DOUBLE"
    , "GRAPHIC" = USP_DATATYPES_UPDATE."GRAPHIC"
    , "INTEGER" = USP_DATATYPES_UPDATE."INTEGER"
    , "REAL" = USP_DATATYPES_UPDATE."REAL"
    , "SMALLINT" = USP_DATATYPES_UPDATE."SMALLINT"
    , "TIME" = USP_DATATYPES_UPDATE."TIME"
    , "TIMESTAMP" = USP_DATATYPES_UPDATE."TIMESTAMP"
    , "TIMESTAMP0" = USP_DATATYPES_UPDATE."TIMESTAMP0"
    , "TIMESTAMP3" = USP_DATATYPES_UPDATE."TIMESTAMP3"
    , "VARBINARY" = USP_DATATYPES_UPDATE."VARBINARY"
    , "VARCHAR" = USP_DATATYPES_UPDATE."VARCHAR"
    , "VARGRAPHIC" = USP_DATATYPES_UPDATE."VARGRAPHIC"
    , "XML" = USP_DATATYPES_UPDATE."XML"
WHERE
    ID = USP_DATATYPES_UPDATE.ID;

END P1
%%

CREATE OR REPLACE PROCEDURE S13.USP_ODBC_DATATYPES (
    )
    READS SQL DATA
    DETERMINISTIC
    CALLED ON NULL INPUT
    LANGUAGE SQL
P1: BEGIN

DECLARE Cursor1 CURSOR WITH RETURN FOR
SELECT
    t."ID"
    , t."BIGINT"
    , t."BINARY"
    , VARCHAR_FORMAT_BIT(CAST("BINARY16" AS CHAR(16) FOR BIT DATA), 'xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx') AS "BINARY16"
    , t."CHAR"
    , t."CHAR36"
    , VARCHAR(t."CLOB") AS "CLOB"
    , t."DATE"
    , VARCHAR(t."DBCLOB") AS "DBCLOB"
    , VARCHAR(t."DECFLOAT") AS "DECFLOAT"
    , CAST(t."DECIMAL152" AS DOUBLE) AS "DECIMAL152"
    , CAST(t."DECIMAL154" AS DOUBLE) AS "DECIMAL154"
    , VARCHAR(t."DECIMAL310") AS "DECIMAL310"
    , VARCHAR(t."DECIMAL314") AS "DECIMAL314"
    , t."DOUBLE"
    , t."GRAPHIC"
    , t."INTEGER"
    , t."REAL"
    , t."SMALLINT"
    , t."TIME"
    , t."TIMESTAMP"
    , t."TIMESTAMP0"
    , t."TIMESTAMP3"
    , t."VARBINARY"
    , t."VARCHAR"
    , t."VARGRAPHIC"
    , VARCHAR(XMLSERIALIZE(t."XML" AS CLOB)) AS "XML"
FROM
    S13.DATATYPES t;

OPEN Cursor1;

END P1
%%

CREATE OR REPLACE PROCEDURE S13.USP_ODBC_DATATYPES_DELETE (
    ID INTEGER
    )
    MODIFIES SQL DATA
    NOT DETERMINISTIC
    CALLED ON NULL INPUT
    COMMIT ON RETURN YES
    LANGUAGE SQL
P1: BEGIN

DELETE FROM S13.DATATYPES t
WHERE
    t.ID = USP_ODBC_DATATYPES_DELETE.ID;

END P1
%%

CREATE OR REPLACE PROCEDURE S13.USP_ODBC_DATATYPES_INSERT (
    "BIGINT" BIGINT
    , "BINARY" BINARY(8)
    , "BINARY16" CHARACTER(36)
    , "CHAR" CHARACTER(10)
    , "CHAR36" CHARACTER(36)
    , "CLOB" CLOB
    , "DATE" DATE
    , "DBCLOB" DBCLOB
    , "DECFLOAT" DECFLOAT
    , "DECIMAL152" DECIMAL(15,2)
    , "DECIMAL154" DECIMAL(15,4)
    , "DECIMAL310" DECIMAL(31,0)
    , "DECIMAL314" DECIMAL(31,4)
    , "DOUBLE" DOUBLE
    , "GRAPHIC" GRAPHIC(10)
    , "INTEGER" INTEGER
    , "REAL" REAL
    , "SMALLINT" SMALLINT
    , "TIME" TIME
    , "TIMESTAMP" TIMESTAMP
    , "TIMESTAMP0" TIMESTAMP(0)
    , "TIMESTAMP3" TIMESTAMP(3)
    , "VARBINARY" VARBINARY(1024)
    , "VARCHAR" VARCHAR(255)
    , "VARGRAPHIC" VARGRAPHIC(1024)
    , "XML" XML
    )
    MODIFIES SQL DATA
    NOT DETERMINISTIC
    CALLED ON NULL INPUT
    COMMIT ON RETURN YES
    LANGUAGE SQL
P1: BEGIN

INSERT INTO S13.DATATYPES
    ( "BIGINT"
    , "BINARY"
    , "BINARY16"
    , "CHAR"
    , "CHAR36"
    , "CLOB"
    , "DATE"
    , "DBCLOB"
    , "DECFLOAT"
    , "DECIMAL152"
    , "DECIMAL154"
    , "DECIMAL310"
    , "DECIMAL314"
    , "DOUBLE"
    , "GRAPHIC"
    , "INTEGER"
    , "REAL"
    , "SMALLINT"
    , "TIME"
    , "TIMESTAMP"
    , "TIMESTAMP0"
    , "TIMESTAMP3"
    , "VARBINARY"
    , "VARCHAR"
    , "VARGRAPHIC"
    , "XML"
    )
VALUES
    ( "BIGINT"
    , "BINARY"
    , VARCHAR_BIT_FORMAT(LOWER("BINARY16"),'xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx')
    , "CHAR"
    , "CHAR36"
    , "CLOB"
    , "DATE"
    , "DBCLOB"
    , "DECFLOAT"
    , "DECIMAL152"
    , "DECIMAL154"
    , "DECIMAL310"
    , "DECIMAL314"
    , "DOUBLE"
    , "GRAPHIC"
    , "INTEGER"
    , "REAL"
    , "SMALLINT"
    , "TIME"
    , "TIMESTAMP"
    , "TIMESTAMP0"
    , "TIMESTAMP3"
    , "VARBINARY"
    , "VARCHAR"
    , "VARGRAPHIC"
    , "XML"
    );

END P1
%%

CREATE OR REPLACE PROCEDURE S13.USP_ODBC_DATATYPES_UPDATE (
    "ID" INTEGER
    , "BIGINT" BIGINT
    , "BINARY" BINARY(8)
    , "BINARY16" CHARACTER(36)
    , "CHAR" CHARACTER(10)
    , "CHAR36" CHARACTER(36)
    , "CLOB" CLOB
    , "DATE" DATE
    , "DBCLOB" DBCLOB
    , "DECFLOAT" DECFLOAT
    , "DECIMAL152" DECIMAL(15,2)
    , "DECIMAL154" DECIMAL(15,4)
    , "DECIMAL310" DECIMAL(31,0)
    , "DECIMAL314" DECIMAL(31,4)
    , "DOUBLE" DOUBLE
    , "GRAPHIC" GRAPHIC(10)
    , "INTEGER" INTEGER
    , "REAL" REAL
    , "SMALLINT" SMALLINT
    , "TIME" TIME
    , "TIMESTAMP" TIMESTAMP
    , "TIMESTAMP0" TIMESTAMP(0)
    , "TIMESTAMP3" TIMESTAMP(3)
    , "VARBINARY" VARBINARY(1024)
    , "VARCHAR" VARCHAR(255)
    , "VARGRAPHIC" VARGRAPHIC(1024)
    , "XML" XML
    )
    MODIFIES SQL DATA
    NOT DETERMINISTIC
    CALLED ON NULL INPUT
    COMMIT ON RETURN YES
    LANGUAGE SQL
P1: BEGIN

UPDATE S13.DATATYPES
SET
    "BIGINT" = USP_ODBC_DATATYPES_UPDATE."BIGINT"
    , "BINARY" = USP_ODBC_DATATYPES_UPDATE."BINARY"
    , "BINARY16" = VARCHAR_BIT_FORMAT(LOWER(USP_ODBC_DATATYPES_UPDATE."BINARY16"), 'xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx')
    , "CHAR" = USP_ODBC_DATATYPES_UPDATE."CHAR"
    , "CHAR36" = USP_ODBC_DATATYPES_UPDATE."CHAR36"
    , "CLOB" = USP_ODBC_DATATYPES_UPDATE."CLOB"
    , "DATE" = USP_ODBC_DATATYPES_UPDATE."DATE"
    , "DBCLOB" = USP_ODBC_DATATYPES_UPDATE."DBCLOB"
    , "DECFLOAT" = USP_ODBC_DATATYPES_UPDATE."DECFLOAT"
    , "DECIMAL152" = USP_ODBC_DATATYPES_UPDATE."DECIMAL152"
    , "DECIMAL154" = USP_ODBC_DATATYPES_UPDATE."DECIMAL154"
    , "DECIMAL310" = USP_ODBC_DATATYPES_UPDATE."DECIMAL310"
    , "DECIMAL314" = USP_ODBC_DATATYPES_UPDATE."DECIMAL314"
    , "DOUBLE" = USP_ODBC_DATATYPES_UPDATE."DOUBLE"
    , "GRAPHIC" = USP_ODBC_DATATYPES_UPDATE."GRAPHIC"
    , "INTEGER" = USP_ODBC_DATATYPES_UPDATE."INTEGER"
    , "REAL" = USP_ODBC_DATATYPES_UPDATE."REAL"
    , "SMALLINT" = USP_ODBC_DATATYPES_UPDATE."SMALLINT"
    , "TIME" = USP_ODBC_DATATYPES_UPDATE."TIME"
    , "TIMESTAMP" = USP_ODBC_DATATYPES_UPDATE."TIMESTAMP"
    , "TIMESTAMP0" = USP_ODBC_DATATYPES_UPDATE."TIMESTAMP0"
    , "TIMESTAMP3" = USP_ODBC_DATATYPES_UPDATE."TIMESTAMP3"
    , "VARBINARY" = USP_ODBC_DATATYPES_UPDATE."VARBINARY"
    , "VARCHAR" = USP_ODBC_DATATYPES_UPDATE."VARCHAR"
    , "VARGRAPHIC" = USP_ODBC_DATATYPES_UPDATE."VARGRAPHIC"
    , "XML" = USP_ODBC_DATATYPES_UPDATE."XML"
WHERE
    ID = USP_ODBC_DATATYPES_UPDATE.ID;

END P1
%%

--#SET TERMINATOR ;

INSERT INTO "S13"."DATATYPES" ("BIGINT","BINARY","BINARY16","BLOB","CHAR","CHAR36","CLOB","DATE","DBCLOB","DECFLOAT","DECIMAL152","DECIMAL154","DECIMAL310","DECIMAL314","DOUBLE","GRAPHIC","INTEGER","REAL","SMALLINT","TIME","TIMESTAMP","TIMESTAMP0","TIMESTAMP3","VARBINARY","VARCHAR","VARGRAPHIC","XML") VALUES (123456789012345,blob(X'0A0B0C0000000000'),blob(X'000102030405060708090A0B0C0D0E0F'),blob(X'0A0B0C'),'char      ','00010203-0405-0607-0809-0a0b0c0d0e0f','clob','2021-12-10','DBCLOB',123456789012.12,123456789012.12,1234567890.1234,123456789012.12,123456789012.1234,123456789012.12,'graphic   ',2147483647,1234567,32767,'15:20:10','2021-12-10 15:20:10.123456','2021-12-10 15:20:10','2021-12-10 15:20:10.123',blob(X'0A0B0C'),'varchar','vargraphic','<xml/>');
INSERT INTO "S13"."DATATYPES" ("BIGINT","BINARY","BINARY16","BLOB","CHAR","CHAR36","CLOB","DATE","DBCLOB","DECFLOAT","DECIMAL152","DECIMAL154","DECIMAL310","DECIMAL314","DOUBLE","GRAPHIC","INTEGER","REAL","SMALLINT","TIME","TIMESTAMP","TIMESTAMP0","TIMESTAMP3","VARBINARY","VARCHAR","VARGRAPHIC","XML") VALUES (123456789012345,blob(X'0A0B0C0000000000'),blob(X'000102030405060708090A0B0C0D0E0F'),blob(X'0A0B0C'),'char      ','00010203-0405-0607-0809-0a0b0c0d0e0f','clob','2021-12-10','DBCLOB',123456789012.12,123456789012.12,1234567890.1234,123456789012.12,123456789012.1234,123456789012.12,'graphic   ',2147483647,1234567,32767,'15:20:10','2021-12-10 15:20:10.123456','2021-12-10 15:20:10','2021-12-10 15:20:10.123',blob(X'0A0B0C'),'varchar','vargraphic','<xml/>');
INSERT INTO "S13"."DATATYPES" ("BIGINT") VALUES (NULL);

INSERT INTO "S13"."QUOTES" ("'", "''", ",", "-", "@", "@@", "`", "``", """", """""", "]", "[", "[]", "+", "*", "%", "%%", "=", ";", ":", "<>", "&", ".", "..") VALUES ('''', '''''', ',', '-', '@', '@@', '`', '``', '"', '""', ']', '[', '[]', '+', '*', '%', '%%', '=', ';', ':', '<>', '&', '.', '..');
INSERT INTO "S13"."QUOTES" ("'", "''", ",", "-", "@", "@@", "`", "``", """", """""", "]", "[", "[]", "+", "*", "%", "%%", "=", ";", ":", "<>", "&", ".", "..") VALUES ('1', '2', '3', '4', '5', '6', '`', '``', '"', '""', ']', '[', '[]', '+', '*', '%', '%%', '=', ';', ':', '<>', '&', '.', '..');

prompt Application installed
