--#SET TERMINATOR ;

-- =============================================
-- SaveToDB Framework Extension for IBM DB2
-- Version 10.8, January 9, 2023
--
-- This script updates SaveToDB Framework 9 to the latest version
--
-- Copyright 2022-2023 Gartle LLC
--
-- License: MIT
-- =============================================

SELECT CASE WHEN 1008 <= CAST(CAST(SUBSTR(HANDLER_CODE, 1, INSTR(HANDLER_CODE, '.') - 1) AS VARCHAR(10)) AS INT) * 100 + CAST(CAST(SUBSTR(HANDLER_CODE, INSTR(HANDLER_CODE, '.') + 1) AS VARCHAR(10)) AS DECIMAL) THEN 'SaveToDB Framework is up-to-date. Update skipped' ELSE HANDLER_CODE END AS CHECK_VERSION FROM XLS.HANDLERS WHERE TABLE_SCHEMA = 'XLS' AND TABLE_NAME = 'SAVETODB_FRAMEWORK_EXTENSION' AND COLUMN_NAME = 'VERSION' AND EVENT_NAME = 'Information' LIMIT 1;

UPDATE XLS.HANDLERS t
SET
    HANDLER_CODE = s.HANDLER_CODE
    , TARGET_WORKSHEET = s.TARGET_WORKSHEET
    , MENU_ORDER = s.MENU_ORDER
    , EDIT_PARAMETERS = s.EDIT_PARAMETERS
FROM
    (
    SELECT
        CAST(NULL AS VARCHAR) AS TABLE_SCHEMA
        , CAST(NULL AS VARCHAR) AS TABLE_NAME
        , CAST(NULL AS VARCHAR) AS COLUMN_NAME
        , CAST(NULL AS VARCHAR) AS EVENT_NAME
        , CAST(NULL AS VARCHAR) AS HANDLER_SCHEMA
        , CAST(NULL AS VARCHAR) AS HANDLER_NAME
        , CAST(NULL AS VARCHAR) AS HANDLER_TYPE
        , CAST(NULL AS VARCHAR) HANDLER_CODE
        , CAST(NULL AS VARCHAR) AS TARGET_WORKSHEET
        , CAST(NULL AS SMALLINT) AS MENU_ORDER
        , CAST(NULL AS SMALLINT) AS EDIT_PARAMETERS
    FROM SYSIBM.SYSDUMMY1

    UNION ALL SELECT 'XLS', 'SAVETODB_FRAMEWORK_EXTENSION', 'VERSION', 'Information', NULL, NULL, 'ATTRIBUTE', '10.8', NULL, NULL, NULL FROM SYSIBM.SYSDUMMY1
    UNION ALL SELECT 'XLS', 'USERS', NULL, 'ACTIONS', 'XLS', 'XL_ACTIONS_SET_EXTENDED_ROLE_PERMISSIONS', 'PROCEDURE', NULL, '_MsgBox', 22, 1 FROM SYSIBM.SYSDUMMY1
    UNION ALL SELECT 'XLS', 'USERS', NULL, 'ACTIONS', 'XLS', 'XL_ACTIONS_REVOKE_EXTENDED_ROLE_PERMISSIONS', 'PROCEDURE', NULL, '_MsgBox', 23, 1 FROM SYSIBM.SYSDUMMY1

    ) s
WHERE
    s.TABLE_NAME IS NOT NULL
    AND t.TABLE_SCHEMA = s.TABLE_SCHEMA
    AND t.TABLE_NAME = s.TABLE_NAME
    AND COALESCE(t.COLUMN_NAME, '') = COALESCE(s.COLUMN_NAME, '')
    AND t.EVENT_NAME = s.EVENT_NAME
    AND COALESCE(t.HANDLER_SCHEMA, '') = COALESCE(s.HANDLER_SCHEMA, '')
    AND COALESCE(t.HANDLER_NAME, '') = COALESCE(s.HANDLER_NAME, '')
    AND COALESCE(t.HANDLER_TYPE, '') = COALESCE(s.HANDLER_TYPE, '')
    AND (
    NOT COALESCE(t.HANDLER_CODE, '') = COALESCE(s.HANDLER_CODE, '')
    OR NOT COALESCE(t.TARGET_WORKSHEET, '') = COALESCE(s.TARGET_WORKSHEET, '')
    OR NOT COALESCE(t.MENU_ORDER, -1) = COALESCE(s.MENU_ORDER, -1)
    OR NOT COALESCE(t.EDIT_PARAMETERS, 0) = COALESCE(s.EDIT_PARAMETERS, 0)
    );

INSERT INTO XLS.HANDLERS
    ( TABLE_SCHEMA
    , TABLE_NAME
    , COLUMN_NAME
    , EVENT_NAME
    , HANDLER_SCHEMA
    , HANDLER_NAME
    , HANDLER_TYPE
    , HANDLER_CODE
    , TARGET_WORKSHEET
    , MENU_ORDER
    , EDIT_PARAMETERS
    )
SELECT
    s.TABLE_SCHEMA
    , s.TABLE_NAME
    , s.COLUMN_NAME
    , s.EVENT_NAME
    , s.HANDLER_SCHEMA
    , s.HANDLER_NAME
    , s.HANDLER_TYPE
    , s.HANDLER_CODE
    , s.TARGET_WORKSHEET
    , s.MENU_ORDER
    , s.EDIT_PARAMETERS
FROM
    (
    SELECT
        CAST(NULL AS VARCHAR) AS TABLE_SCHEMA
        , CAST(NULL AS VARCHAR) AS TABLE_NAME
        , CAST(NULL AS VARCHAR) AS COLUMN_NAME
        , CAST(NULL AS VARCHAR) AS EVENT_NAME
        , CAST(NULL AS VARCHAR) AS HANDLER_SCHEMA
        , CAST(NULL AS VARCHAR) AS HANDLER_NAME
        , CAST(NULL AS VARCHAR) AS HANDLER_TYPE
        , CAST(NULL AS VARCHAR) HANDLER_CODE
        , CAST(NULL AS VARCHAR) AS TARGET_WORKSHEET
        , CAST(NULL AS SMALLINT) AS MENU_ORDER
        , CAST(NULL AS SMALLINT) AS EDIT_PARAMETERS
    FROM SYSIBM.SYSDUMMY1

    UNION ALL SELECT 'XLS', 'SAVETODB_FRAMEWORK_EXTENSION', 'VERSION', 'Information', NULL, NULL, 'ATTRIBUTE', '10.8', NULL, NULL, NULL FROM SYSIBM.SYSDUMMY1
    UNION ALL SELECT 'XLS', 'USERS', NULL, 'ACTIONS', 'XLS', 'XL_ACTIONS_SET_EXTENDED_ROLE_PERMISSIONS', 'PROCEDURE', NULL, '_MsgBox', 22, 1 FROM SYSIBM.SYSDUMMY1
    UNION ALL SELECT 'XLS', 'USERS', NULL, 'ACTIONS', 'XLS', 'XL_ACTIONS_REVOKE_EXTENDED_ROLE_PERMISSIONS', 'PROCEDURE', NULL, '_MsgBox', 23, 1 FROM SYSIBM.SYSDUMMY1

    ) s
    LEFT OUTER JOIN XLS.HANDLERS T ON
        t.TABLE_SCHEMA = s.TABLE_SCHEMA
        AND t.TABLE_NAME = s.TABLE_NAME
        AND COALESCE(t.COLUMN_NAME, '') = COALESCE(s.COLUMN_NAME, '')
        AND t.EVENT_NAME = s.EVENT_NAME
        AND COALESCE(t.HANDLER_SCHEMA, '') = COALESCE(s.HANDLER_SCHEMA, '')
        AND COALESCE(t.HANDLER_NAME, '') = COALESCE(s.HANDLER_NAME, '')
        AND COALESCE(t.HANDLER_TYPE, '') = COALESCE(s.HANDLER_TYPE, '')
WHERE
    t.TABLE_NAME IS NULL
    AND s.TABLE_NAME IS NOT NULL;

--#SET TERMINATOR %%

CREATE OR REPLACE PROCEDURE XLS.XL_ACTIONS_SET_EXTENDED_ROLE_PERMISSIONS (
    )
    MODIFIES SQL DATA
    COMMIT ON RETURN YES
    LANGUAGE SQL
P1: BEGIN

    GRANT SELECT ON TABLE XLS.VIEW_COLUMNS          TO ROLE XLS_USERS;
    GRANT SELECT ON TABLE XLS.VIEW_FORMATS          TO ROLE XLS_USERS;
    GRANT SELECT ON TABLE XLS.VIEW_HANDLERS         TO ROLE XLS_USERS;
    GRANT SELECT ON TABLE XLS.VIEW_OBJECTS          TO ROLE XLS_USERS;
    GRANT SELECT ON TABLE XLS.VIEW_TRANSLATIONS     TO ROLE XLS_USERS;
    GRANT SELECT ON TABLE XLS.VIEW_QUERIES          TO ROLE XLS_USERS;
    GRANT SELECT ON TABLE XLS.VIEW_WORKBOOKS        TO ROLE XLS_USERS;

    GRANT SELECT ON TABLE XLS.COLUMNS               TO ROLE XLS_USERS;
    GRANT SELECT ON TABLE XLS.FORMATS               TO ROLE XLS_USERS;
    GRANT SELECT ON TABLE XLS.HANDLERS              TO ROLE XLS_USERS;
    GRANT SELECT ON TABLE XLS.OBJECTS               TO ROLE XLS_USERS;
    GRANT SELECT ON TABLE XLS.TRANSLATIONS          TO ROLE XLS_USERS;
    GRANT SELECT ON TABLE XLS.QUERIES               TO ROLE XLS_USERS;
    GRANT SELECT ON TABLE XLS.WORKBOOKS             TO ROLE XLS_USERS;

    REVOKE SELECT ON TABLE XLS.COLUMNS              FROM ROLE XLS_USERS;
    REVOKE SELECT ON TABLE XLS.FORMATS              FROM ROLE XLS_USERS;
    REVOKE SELECT ON TABLE XLS.HANDLERS             FROM ROLE XLS_USERS;
    REVOKE SELECT ON TABLE XLS.OBJECTS              FROM ROLE XLS_USERS;
    REVOKE SELECT ON TABLE XLS.TRANSLATIONS         FROM ROLE XLS_USERS;
    REVOKE SELECT ON TABLE XLS.QUERIES              FROM ROLE XLS_USERS;
    REVOKE SELECT ON TABLE XLS.WORKBOOKS            FROM ROLE XLS_USERS;

    GRANT EXECUTE ON PROCEDURE XLS.XL_UPDATE_TABLE_FORMAT TO ROLE XLS_FORMATS;

    GRANT SELECT, INSERT, UPDATE, DELETE ON TABLE XLS.FORMATS TO ROLE XLS_FORMATS;

    REVOKE SELECT, INSERT, UPDATE, DELETE ON TABLE XLS.FORMATS FROM ROLE XLS_FORMATS;

END P1
%%

CREATE OR REPLACE PROCEDURE XLS.XL_ACTIONS_REVOKE_EXTENDED_ROLE_PERMISSIONS (
    )
    MODIFIES SQL DATA
    COMMIT ON RETURN YES
    LANGUAGE SQL
P1: BEGIN

    GRANT SELECT ON TABLE XLS.VIEW_COLUMNS          TO ROLE XLS_USERS;
    GRANT SELECT ON TABLE XLS.VIEW_FORMATS          TO ROLE XLS_USERS;
    GRANT SELECT ON TABLE XLS.VIEW_HANDLERS         TO ROLE XLS_USERS;
    GRANT SELECT ON TABLE XLS.VIEW_OBJECTS          TO ROLE XLS_USERS;
    GRANT SELECT ON TABLE XLS.VIEW_TRANSLATIONS     TO ROLE XLS_USERS;
    GRANT SELECT ON TABLE XLS.VIEW_QUERIES          TO ROLE XLS_USERS;
    GRANT SELECT ON TABLE XLS.VIEW_WORKBOOKS        TO ROLE XLS_USERS;

    REVOKE SELECT ON TABLE XLS.VIEW_COLUMNS         FROM ROLE XLS_USERS;
    REVOKE SELECT ON TABLE XLS.VIEW_FORMATS         FROM ROLE XLS_USERS;
    REVOKE SELECT ON TABLE XLS.VIEW_HANDLERS        FROM ROLE XLS_USERS;
    REVOKE SELECT ON TABLE XLS.VIEW_OBJECTS         FROM ROLE XLS_USERS;
    REVOKE SELECT ON TABLE XLS.VIEW_TRANSLATIONS    FROM ROLE XLS_USERS;
    REVOKE SELECT ON TABLE XLS.VIEW_QUERIES         FROM ROLE XLS_USERS;
    REVOKE SELECT ON TABLE XLS.VIEW_WORKBOOKS       FROM ROLE XLS_USERS;

    GRANT SELECT ON TABLE XLS.COLUMNS               TO ROLE XLS_USERS;
    GRANT SELECT ON TABLE XLS.FORMATS               TO ROLE XLS_USERS;
    GRANT SELECT ON TABLE XLS.HANDLERS              TO ROLE XLS_USERS;
    GRANT SELECT ON TABLE XLS.OBJECTS               TO ROLE XLS_USERS;
    GRANT SELECT ON TABLE XLS.TRANSLATIONS          TO ROLE XLS_USERS;
    GRANT SELECT ON TABLE XLS.QUERIES               TO ROLE XLS_USERS;
    GRANT SELECT ON TABLE XLS.WORKBOOKS             TO ROLE XLS_USERS;

    GRANT EXECUTE ON PROCEDURE XLS.XL_UPDATE_TABLE_FORMAT TO ROLE XLS_FORMATS;

    REVOKE EXECUTE ON PROCEDURE XLS.XL_UPDATE_TABLE_FORMAT FROM ROLE XLS_FORMATS;

    GRANT SELECT, INSERT, UPDATE, DELETE ON TABLE XLS.FORMATS TO ROLE XLS_FORMATS;

END P1
%%

--#SET TERMINATOR ;

echo SaveToDB Framework Extension updated
