-- =============================================
-- SaveToDB Framework for IBM DB2
-- Version 8.15, November 7, 2018
--
-- This script upgrades SaveToDB Framework 8.11 to SaveToDB Framework 8.15
--
-- Copyright 2012-2018 Gartle Technology Corporation
-- =============================================

UPDATE XLS.HANDLERS  SET HANDLER_CODE = 'TABLE, VIEW, PROCEDURE, FUNCTION, CODE, HTTP, TEXT, MACRO, CMD, VALUES, RANGE, REFRESH, MENUSEPARATOR, PDF, REPORT, SHOWSHEETS, HIDESHEETS, SELECTSHEET' WHERE TABLE_SCHEMA = 'XLS' AND TABLE_NAME = 'HANDLERS' AND COLUMN_NAME = 'HANDLER_TYPE' AND EVENT_NAME = 'ValidationList';

CREATE OR REPLACE VIEW XLS.QUERIES (
    TABLE_SCHEMA,
    TABLE_NAME,
    TABLE_TYPE,
    TABLE_CODE,
    INSERT_PROCEDURE,
    UPDATE_PROCEDURE,
    DELETE_PROCEDURE,
    PROCEDURE_TYPE
    )
AS
SELECT
    t.TABSCHEMA AS TABLE_SCHEMA
    , t.TABNAME AS TABLE_NAME
    , CASE t."TYPE"
        WHEN 'T' THEN 'TABLE'
        WHEN 'V' THEN 'VIEW'
        ELSE TYPE
        END AS TABLE_TYPE
    , NULL AS TABLE_CODE
    , NULL AS INSERT_PROCEDURE
    , NULL AS UPDATE_PROCEDURE
    , NULL AS DELETE_PROCEDURE
    , NULL AS PROCEDURE_TYPE
FROM
    SYSCAT.TABLES t
WHERE
    t.TABSCHEMA NOT IN ('SYSCAT', 'SYSIBM', 'SYSIBMADM', 'SYSTOOLS', 'SYSSTAT')
    AND t."TYPE" IN ('T', 'V')
    AND NOT t.TABNAME LIKE 'XL_%'
UNION ALL
SELECT
    t.ROUTINESCHEMA AS TABLE_SCHEMA
    , t.ROUTINENAME AS TABLE_NAME
    , 'PROCEDURE' AS TABLE_TYPE
    , NULL AS TABLE_CODE
    , NULL AS INSERT_PROCEDURE
    , NULL AS UPDATE_PROCEDURE
    , NULL AS DELETE_PROCEDURE
    , NULL AS PROCEDURE_TYPE
FROM
    SYSCAT.ROUTINES t
WHERE
    t.ROUTINESCHEMA NOT IN ('SYSCAT', 'SYSIBM', 'SYSIBMADM', 'SYSPROC', 'SYSTOOLS', 'SYSSTAT')
    AND t.ROUTINETYPE = 'P'
    AND t.RESULT_SETS = 1
    AND t.LANGUAGE = 'SQL'
    AND t.ROUTINENAME NOT LIKE '%_INSERT'
    AND t.ROUTINENAME NOT LIKE '%_UPDATE'
    AND t.ROUTINENAME NOT LIKE '%_DELETE'
    AND t.ROUTINENAME NOT LIKE '%_MERGE'
    AND t.ROUTINENAME NOT LIKE '%_CHANGE'
    AND t.ROUTINENAME NOT LIKE 'XL_%'
UNION ALL
SELECT
    o.TABLE_SCHEMA
    , o.TABLE_NAME
    , o.TABLE_TYPE
    , o.TABLE_CODE
    , o.INSERT_OBJECT AS INSERT_PROCEDURE
    , o.UPDATE_OBJECT AS UPDATE_PROCEDURE
    , o.DELETE_OBJECT AS DELETE_PROCEDURE
    , NULL AS PROCEDURE_TYPE
FROM
    XLS.OBJECTS o
WHERE
    o.TABLE_TYPE IN ('CODE', 'HTTP', 'TEXT')
    AND o.TABLE_SCHEMA IS NOT NULL
    AND o.TABLE_NAME IS NOT NULL
    AND o.TABLE_CODE IS NOT NULL
    AND NOT o.TABLE_NAME LIKE 'XL_%'
;
